<?php

require_once get_template_directory() . '/includes/loader.php';

add_action( 'after_setup_theme', 'timisoara_setup_theme' );
add_action( 'after_setup_theme', 'timisoara_load_default_hooks' );


function timisoara_setup_theme() {

	load_theme_textdomain( 'timisoara', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );
	add_theme_support( 'custom-header' );
	add_theme_support( 'custom-background' );
	add_theme_support('woocommerce');
	add_theme_support('wc-product-gallery-lightbox');
	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'wp-block-styles' );
	add_theme_support( 'align-wide' );
	add_theme_support( 'wp-block-styles' );
	add_theme_support( 'editor-styles' );


	// Set the default content width.
	$GLOBALS['content_width'] = 525;
	
	/*---------- Register image sizes ----------*/
	
	//Register image sizes
	add_image_size( 'timisoara_370x310', 370, 310, true ); //'timisoara_370x310 Our Services'
	add_image_size( 'timisoara_70x70', 70, 70, true ); //'timisoara_70x70 Our Testimonials'
	add_image_size( 'timisoara_370x290', 370, 290, true ); //'timisoara_370x290 Latest News'
	add_image_size( 'timisoara_440x305', 440, 305, true ); //'timisoara_440x305 Our Team'
	add_image_size( 'timisoara_310x305', 310, 305, true ); //'timisoara_310x305 Our Team V2'
	add_image_size( 'timisoara_1170x440', 1170, 440, true ); //'timisoara_1170x440 Our Blog'
	/*---------- Register image sizes ends ----------*/
	
	
	
	// This theme uses wp_nav_menu() in two locations.
	register_nav_menus( array(
		'main_menu' => esc_html__( 'Main Menu', 'timisoara' ),
		'rtl_menu' => esc_html__( 'RTL Menu', 'timisoara' ),
		'onepage_menu' => esc_html__( 'OnePage Menu', 'timisoara' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	// Add theme support for Custom Logo.
	add_theme_support( 'custom-logo', array(
		'width'      => 250,
		'height'     => 250,
		'flex-width' => true,
	) );

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );

	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, and column width.
 	 */
	add_editor_style();
	add_action( 'admin_init', 'timisoara_admin_init', 2000000 );
}

/**
 * [timisoara_admin_init]
 *
 * @param  array $data [description]
 *
 * @return [type]       [description]
 */


function timisoara_admin_init() {
	remove_action( 'admin_notices', array( 'ReduxFramework', '_admin_notices' ), 99 );
}

/*---------- Sidebar settings ----------*/

/**
 * [timisoara_widgets_init]
 *
 * @param  array $data [description]
 *
 * @return [type]       [description]
 */
function timisoara_widgets_init() {

	global $wp_registered_sidebars;

	$theme_options = get_theme_mod( 'timisoara' . '_options-mods' );

	register_sidebar( array(
		'name'          => esc_html__( 'Default Sidebar', 'timisoara' ),
		'id'            => 'default-sidebar',
		'description'   => esc_html__( 'Widgets in this area will be shown on the right-hand side.', 'timisoara' ),
		'before_widget' => '<div id="%1$s" class="mrwidget widget sidebar-widget single-sidebar %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<div class="sidebar-title"><h3>',
		'after_title'   => '</h3></div>',
	) );
	register_sidebar(array(
		'name' => esc_html__('Footer Widget', 'timisoara'),
		'id' => 'footer-sidebar',
		'description' => esc_html__('Widgets in this area will be shown in Footer Area.', 'timisoara'),
		'before_widget'=>'<div class="col-xl-4 col-lg-6 col-md-6 col-sm-12 footer-column"><div id="%1$s" class="footer-widget single-footer-widget %2$s">',
		'after_widget'=>'</div></div>',
		'before_title' => '<div class="sidebar-title"><h3>',
		'after_title' => '</h3></div>'
	));
	if ( class_exists( '\Elementor\Plugin' )){
	register_sidebar(array(
		'name' => esc_html__('RTL Footer Widget', 'timisoara'),
		'id' => 'footer-sidebar-2',
		'description' => esc_html__('Widgets in this area will be shown in Footer Area.', 'timisoara'),
		'before_widget'=>'<div class="col-xl-3 col-lg-6 col-md-6 col-sm-12 footer-column"><div id="%1$s" class="footer-widget single-footer-widget %2$s">',
		'after_widget'=>'</div></div>',
		'before_title' => '<div class="sidebar-title"><h3>',
		'after_title' => '</h3></div>'
	));
	register_sidebar(array(
		'name' => esc_html__('Services Widget', 'timisoara'),
		'id' => 'service-sidebar',
	'description'   => esc_html__( 'Widgets in this area will be shown on the right-hand side.', 'timisoara' ),
		'before_widget' => '<div id="%1$s" class="mrwidget widget sidebar-widget single-sidebar %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<div class="sidebar-title"><h3>',
		'after_title'   => '</h3></div>',
	));
	}
	register_sidebar(array(
	  'name' => esc_html__( 'Blog Listing', 'timisoara' ),
	  'id' => 'blog-sidebar',
		'description'   => esc_html__( 'Widgets in this area will be shown on the right-hand side.', 'timisoara' ),
		'before_widget' => '<div id="%1$s" class="mrwidget widget sidebar-widget single-sidebar %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<div class="sidebar-title"><h3>',
		'after_title'   => '</h3></div>',
	) );
	if ( ! is_object( timisoara_WSH() ) ) {
		return;
	}

	$sidebars = timisoara_set( $theme_options, 'custom_sidebar_name' );

	foreach ( array_filter( (array) $sidebars ) as $sidebar ) {

		if ( timisoara_set( $sidebar, 'topcopy' ) ) {
			continue;
		}

		$name = $sidebar;
		if ( ! $name ) {
			continue;
		}
		$slug = str_replace( ' ', '_', $name );

		register_sidebar( array(
			'name'          => $name,
			'id'            => sanitize_title( $slug ),
			'description'   => esc_html__( 'Widgets in this area will be shown on the right-hand side.', 'timisoara' ),
		'before_widget' => '<div id="%1$s" class="mrwidget widget sidebar-widget single-sidebar %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<div class="sidebar-title"><h3>',
		'after_title'   => '</h3></div>',
		) );
	}

	update_option( 'wp_registered_sidebars', $wp_registered_sidebars );
}

add_action( 'widgets_init', 'timisoara_widgets_init' );

/*---------- Sidebar settings ends ----------*/

/*---------- Gutenberg settings ----------*/

function timisoara_gutenberg_editor_palette_styles() {
    add_theme_support( 'editor-color-palette', array(
        array(
            'name' => esc_html__( 'strong yellow', 'timisoara' ),
            'slug' => 'strong-yellow',
            'color' => '#f7bd00',
        ),
        array(
            'name' => esc_html__( 'strong white', 'timisoara' ),
            'slug' => 'strong-white',
            'color' => '#fff',
        ),
		array(
            'name' => esc_html__( 'light black', 'timisoara' ),
            'slug' => 'light-black',
            'color' => '#242424',
        ),
        array(
            'name' => esc_html__( 'very light gray', 'timisoara' ),
            'slug' => 'very-light-gray',
            'color' => '#797979',
        ),
        array(
            'name' => esc_html__( 'very dark black', 'timisoara' ),
            'slug' => 'very-dark-black',
            'color' => '#000000',
        ),
    ) );
	
	add_theme_support( 'editor-font-sizes', array(
		array(
			'name' => esc_html__( 'Small', 'timisoara' ),
			'size' => 10,
			'slug' => 'small'
		),
		array(
			'name' => esc_html__( 'Normal', 'timisoara' ),
			'size' => 15,
			'slug' => 'normal'
		),
		array(
			'name' => esc_html__( 'Large', 'timisoara' ),
			'size' => 24,
			'slug' => 'large'
		),
		array(
			'name' => esc_html__( 'Huge', 'timisoara' ),
			'size' => 36,
			'slug' => 'huge'
		)
	) );
	
}
add_action( 'after_setup_theme', 'timisoara_gutenberg_editor_palette_styles' );

/*---------- Gutenberg settings ends ----------*/

/*---------- Enqueue Styles and Scripts ----------*/

function timisoara_enqueue_scripts() {

	
    //styles
	wp_enqueue_style( 'animate', get_template_directory_uri() . '/assets/css/animate.css' );
	wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/assets/css/bootstrap.css' );
	wp_enqueue_style( 'flaticon', get_template_directory_uri() . '/assets/css/flaticon.css' );
	wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/assets/css/font-awesome.css' );
	wp_enqueue_style( 'hover', get_template_directory_uri() . '/assets/css/hover.css' );
	wp_enqueue_style( 'icomoon', get_template_directory_uri() . '/assets/css/icomoon.css' );
	wp_enqueue_style( 'fancybox-min', get_template_directory_uri() . '/assets/css/jquery.fancybox.min.css' );
	wp_enqueue_style( 'owl', get_template_directory_uri() . '/assets/css/owl.css' );
	
	
	wp_enqueue_style( 'about-section', get_template_directory_uri() . '/assets/css/about-section.css' );
	wp_enqueue_style( 'chooseus-section', get_template_directory_uri() . '/assets/css/chooseus-section.css' );
	wp_enqueue_style( 'clients-section', get_template_directory_uri() . '/assets/css/clients-section.css' );
	wp_enqueue_style( 'contact-info', get_template_directory_uri() . '/assets/css/contact-info.css' );
	wp_enqueue_style( 'contact-section', get_template_directory_uri() . '/assets/css/contact-section.css' );
	wp_enqueue_style( 'cta-section', get_template_directory_uri() . '/assets/css/cta-section.css' );
	wp_enqueue_style( 'error-section', get_template_directory_uri() . '/assets/css/error-section.css' );
	wp_enqueue_style( 'feature-section', get_template_directory_uri() . '/assets/css/feature-section.css' );
	wp_enqueue_style( 'fluid-section', get_template_directory_uri() . '/assets/css/fluid-section.css' );
	wp_enqueue_style( 'fun-fact-section', get_template_directory_uri() . '/assets/css/fun-fact-section.css' );
	wp_enqueue_style( 'main-slider', get_template_directory_uri() . '/assets/css/main-slider.css' );
	wp_enqueue_style( 'news-detail', get_template_directory_uri() . '/assets/css/news-detail.css' );
	wp_enqueue_style( 'news-section', get_template_directory_uri() . '/assets/css/news-section.css' );
	wp_enqueue_style( 'our-mission', get_template_directory_uri() . '/assets/css/our-mission.css' );
	wp_enqueue_style( 'page-title', get_template_directory_uri() . '/assets/css/page-title.css' );
	wp_enqueue_style( 'pricing-section', get_template_directory_uri() . '/assets/css/pricing-section.css' );
	wp_enqueue_style( 'project-detail', get_template_directory_uri() . '/assets/css/project-detail.css' );
	wp_enqueue_style( 'project-section', get_template_directory_uri() . '/assets/css/project-section.css' );
	wp_enqueue_style( 'service-section', get_template_directory_uri() . '/assets/css/service-section.css' );
	wp_enqueue_style( 'sidebar-page-container', get_template_directory_uri() . '/assets/css/sidebar-page-container.css' );
	wp_enqueue_style( 'subscribe-section', get_template_directory_uri() . '/assets/css/subscribe-section.css' );
	wp_enqueue_style( 'team-section', get_template_directory_uri() . '/assets/css/team-section.css' );
	wp_enqueue_style( 'testimonial-section', get_template_directory_uri() . '/assets/css/testimonial-section.css' );
	wp_enqueue_style( 'video-section', get_template_directory_uri() . '/assets/css/video-section.css' );
	wp_enqueue_style( 'work-section', get_template_directory_uri() . '/assets/css/work-section.css' );
	
	wp_enqueue_style( 'timisoara-error', get_template_directory_uri() . '/assets/css/theme/error.css' );
	wp_enqueue_style( 'timisoara-gutenberg', get_template_directory_uri() . '/assets/css/theme/gutenberg.css' );
	wp_enqueue_style( 'timisoara-fixing', get_template_directory_uri() . '/assets/css/theme/fixing.css' );
	wp_enqueue_style( 'timisoara-sidebar', get_template_directory_uri() . '/assets/css/theme/sidebar.css' );
	wp_enqueue_style( 'timisoara-tut', get_template_directory_uri() . '/assets/css/theme/tut.css' );
	wp_enqueue_style( 'timisoara-rtl', get_template_directory_uri() . '/assets/css/rtl.css' );
	wp_enqueue_style( 'timisoara-color', get_template_directory_uri() . '/assets/css/color.php' );	
	wp_enqueue_style( 'timisoara-main', get_stylesheet_uri() );
	wp_enqueue_style( 'timisoara-style', get_template_directory_uri() . '/assets/css/style.css' );
	wp_enqueue_style( 'timisoara-responsive', get_template_directory_uri() . '/assets/css/responsive.css' );
	wp_enqueue_style( 'woocommerce', get_template_directory_uri() . '/assets/css/woocommerce.css' );
	
    //scripts
	wp_enqueue_script( 'jquery-ui-core');
	wp_enqueue_script( 'jquery', get_template_directory_uri().'/assets/js/jquery.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'appear', get_template_directory_uri().'/assets/js/appear.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'bootstrap-min', get_template_directory_uri().'/assets/js/bootstrap.min.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'isotope', get_template_directory_uri().'/assets/js/isotope.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'fancybox', get_template_directory_uri().'/assets/js/jquery.fancybox.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'paroller-min', get_template_directory_uri().'/assets/js/jquery.paroller.min.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'knob', get_template_directory_uri().'/assets/js/knob.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'mixitup', get_template_directory_uri().'/assets/js/mixitup.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'nav-tool', get_template_directory_uri().'/assets/js/nav-tool.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'owl', get_template_directory_uri().'/assets/js/owl.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'wow', get_template_directory_uri().'/assets/js/wow.js', array( 'jquery' ), '2.1.2', true );
		
	wp_enqueue_script( 'timisoara-main-script', get_template_directory_uri().'/assets/js/script.js', array(), false, true );
	if( is_singular() ) wp_enqueue_script('comment-reply');
	
}
add_action( 'wp_enqueue_scripts', 'timisoara_enqueue_scripts' );

/*---------- Enqueue styles and scripts ends ----------*/

/*---------- Google fonts ----------*/

function timisoara_fonts_url() {
	
	$fonts_url = '';

		$font_families['Poppins']      = 'Poppins:300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';

		$font_families = apply_filters( 'REXAR/includes/classes/header_enqueue/font_families', $font_families );

		$query_args = array(
			'family' => urlencode( implode( '|', $font_families ) ),
			'subset' => urlencode( 'latin,latin-ext' ),
		);

		$protocol  = is_ssl() ? 'https' : 'http';
		$fonts_url = add_query_arg( $query_args, $protocol . '://fonts.googleapis.com/css' );

		return esc_url_raw($fonts_url);

}

function timisoara_theme_styles() {
    wp_enqueue_style( 'timisoara-theme-fonts', timisoara_fonts_url(), array(), null );
}

add_action( 'wp_enqueue_scripts', 'timisoara_theme_styles' );
add_action( 'admin_enqueue_scripts', 'timisoara_theme_styles' );

/*---------- Google fonts ends ----------*/

/*---------- More functions ----------*/

// 1) timisoara_set function

/**
 * [timisoara_set description]
 *
 * @param  array $data [description]
 *
 * @return [type]       [description]
 */
if ( ! function_exists( 'timisoara_set' ) ) {
	function timisoara_set( $var, $key, $def = '' ) {
		//if( ! $var ) return false;

		if ( is_object( $var ) && isset( $var->$key ) ) {
			return $var->$key;
		} elseif ( is_array( $var ) && isset( $var[ $key ] ) ) {
			return $var[ $key ];
		} elseif ( $def ) {
			return $def;
		} else {
			return false;
		}
	}
}

// 2) timisoara_add_editor_styles function

function timisoara_add_editor_styles() {
    add_editor_style( 'editor-style.css' );
}
add_action( 'admin_init', 'timisoara_add_editor_styles' );

// 3) Add specific CSS class by filter body class.

$options = timisoara_WSH()->option(); 
if( timisoara_set($options, 'boxed_wrapper') ){

	add_filter( 'body_class', function( $classes ) {
		$classes[] = 'boxed_wrapper';
		return $classes;
	} );
}

function timisoara_related_products_limit() {
  global $product;
	
	$args['posts_per_page'] = 6;
	return $args;
}
/**
 * product per page
 */
add_filter( 'loop_shop_per_page', 'timisoara_loop_shop_per_page', 20 );

function timisoara_loop_shop_per_page( $cols ) {
		$options     = timisoara_WSH()->option();		
		$shop_product = esc_attr( $options->get( 'shop_product') );	
		
  // $cols contains the current number of products per page based on the value stored on Options –> Reading
  // Return the number of products you wanna show per page.
  $cols =  $shop_product;
  return $cols;
}
function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328629&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        